@@ -34,7 +34,7 @@
 using namespace std;
 using namespace Gtk;
 
-class DialogAbout : public Gtk::Dialog {
+class DialogAbout : public Gtk::AboutDialog {
 public:
   DialogAbout();
   ~DialogAbout();
