@@ -29,7 +29,7 @@ using namespace std;
 
 class DialogError : public Gtk::Dialog {
 public:
-  DialogError(string primary, string primary, Gtk::Window &parent);
+  DialogError(string primary, string secondary, Gtk::Window &parent);
   
 protected:
   void on_signal_response(int response);
